<?php

declare(strict_types=1);

namespace apexl\Io\factories;

use apexl\Io\Client;
use DI\Container;

final readonly class ClientFactory
{
    public function __construct(
        private Container $container,
    ) {}

    public function make(): Client
    {
        return $this->container->make(Client::class);
    }
}