{
  "name": "apexl/{{name}}",
  "description": "An Io Module to...",
  "type": "project",
  "require": {
    "apexl/io": "^2.1.6",
    "php": "^8.2"
  },
  "repositories": [
    {
      "type": "composer",
      "url": "https:\/\/codestore.sc.vg"
    }
  ],
  "autoload": {
    "psr-4": {
      "apexl\\": "src/"
    }
  },
  "license": "MIT",
  "authors": [
  ],
  "require-dev": {
    "friendsofphp/php-cs-fixer": "^3.14"
  }
}
